@@ -1,6 +1,6 @@
 from pydantic import ValidationError
 from pydantic_settings import BaseSettings
-from utils import setup_logger
+from .utils import setup_logger
 
 logger = setup_logger(name="codeaira-config")
 
